@@ -3,6 +3,9 @@ ddelap <- function(x, alpha, beta, lambda, log = FALSE){
   if(!is.double(alpha)) {storage.mode(alpha) <- 'double'}
   if(!is.double(beta)) {storage.mode(beta) <- 'double'}
   if(!is.double(lambda)) {storage.mode(lambda) <- 'double'}
+  if(any(x > floor(x))) {
+    warning("Non-integers passed to ddelap. These will have 0 probability.")
+  }
   .Call(ddelap_C, x, alpha, beta, lambda, log)
 }
 
@@ -33,12 +36,7 @@ qdelap <- function(p, alpha, beta, lambda, lower.tail = TRUE, log.p = FALSE, exa
     pInf <- p[p >= 1]
     n <- min(10 ^ (ceiling(log(alpha * beta + lambda, 10)) + 5), 1e7)
     if (old) {
-      .Deprecated(msg = 'If not using exact, use old = FALSE. The "old" option may be removed at any time and exact = FALSE will default to the new method.',
-                  old = 'old = TRUE',
-                  new = 'old = FALSE')
-      NB <- rnbinom(n, mu = alpha * beta, size = alpha)
-      P <- rpois(n, lambda = lambda)
-      DP <- NB + P
+      .Defunct(msg = 'This option is defunct. Use old = FALSE. The "old" option may be removed at any time and exact = FALSE will default to the new method.')
     } else {
       ShiftedGammas <- rgamma(n, shape = alpha, scale = beta)
       DP <- rpois(n, lambda = (ShiftedGammas + lambda))
@@ -62,17 +60,7 @@ rdelap <- function(n, alpha, beta, lambda, exact = TRUE, old = FALSE){
     if(any(alpha <= 0) || any(beta <= 0) || any(lambda <= 0))
       stop('Parameters must be strictly greater than 0. Please use exact version, if necessary, to prevent spurious results')
     if (old) {
-      .Deprecated(msg = 'If not using exact, use old = FALSE. The "old" option may be removed at any time and exact = FALSE will default to the new method.',
-                  old = 'old = TRUE',
-                  new = 'old = FALSE')
-      NB <- rnbinom(max(1e7, n), mu = alpha * beta, size = alpha)
-      P <- rpois(max(1e7, n), lambda = lambda)
-      DP <- NB + P
-      if (n >= 1e7) {
-        RDLAP <- DP
-      } else {
-        RDLAP <- sample(x = DP, size = n, replace = TRUE)
-      }
+      .Defunct(msg = 'This option is defunct. Use old = FALSE. The "old" option may be removed at any time and exact = FALSE will default to the new method.')
     } else {
       ShiftedGammas <- rgamma(n, shape = alpha, scale = beta)
       RDLAP <- rpois(n, lambda = (ShiftedGammas + lambda))
@@ -90,3 +78,7 @@ MoMdelap <- function(x){
   if (any(MoMDLAP <= 0)) stop ("Method of moments not appropriate for this data; results include non-positive parameters.")
   return(MoMDLAP)
 }
+
+.onUnload <- function (libpath) {
+  library.dynam.unload("Delaporte", libpath)
+}
